@@ -1,4 +1,3 @@
-/* $Xorg: PutImage.c,v 1.4 2001/02/09 02:03:35 xorgcvs Exp $ */
 /*
 
 Copyright 1986, 1998  The Open Group
@@ -24,7 +23,6 @@ used in advertising or otherwise to promote the sale, use or other dealings
 in this Software without prior written authorization from The Open Group.
 
 */
-/* $XFree86: xc/lib/X11/PutImage.c,v 3.11 2002/12/09 04:10:56 tsi Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -602,15 +600,9 @@ static int const HalfOrderWord[12] = {
 
 /* Cancel a GetReq operation, before doing _XSend or Data */
 
-#if (defined(__STDC__) && !defined(UNIXCPP)) || defined(ANSICPP)
 #define UnGetReq(name)\
     dpy->bufptr -= SIZEOF(x##name##Req);\
-    dpy->request--
-#else
-#define UnGetReq(name)\
-    dpy->bufptr -= SIZEOF(x/**/name/**/Req);\
-    dpy->request--
-#endif
+    X_DPY_REQUEST_DECREMENT(dpy)
 
 static void
 SendXYImage(
@@ -682,7 +674,7 @@ SendXYImage(
 
     length = ROUNDUP(length, 4);
     if ((dpy->bufptr + length) > dpy->bufmax) {
-	if ((buf = _XAllocScratch(dpy, (unsigned long) (length))) == NULL) {
+	if ((buf = _XAllocScratch(dpy, length)) == NULL) {
 	    UnGetReq(PutImage);
 	    return;
 	}
@@ -705,13 +697,13 @@ SendXYImage(
 	bytes_per_temp_plane = bytes_per_line * req->height;
 	temp_length = ROUNDUP(bytes_per_temp_plane * image->depth, 4);
 	if (buf == dpy->bufptr) {
-	    if (! (temp = _XAllocScratch(dpy, (unsigned long) temp_length))) {
+	    if (! (temp = _XAllocScratch(dpy, temp_length))) {
 		UnGetReq(PutImage);
 		return;
 	    }
 	}
 	else
-	    if ((extra = temp = Xmalloc((unsigned) temp_length)) == NULL) {
+	    if ((extra = temp = Xmalloc(temp_length)) == NULL) {
 		UnGetReq(PutImage);
 		return;
 	    }
@@ -748,8 +740,7 @@ SendXYImage(
 		    bytes_per_src, bytes_per_line,
 		    bytes_per_dest, req->height, half_order);
 
-    if (extra)
-	Xfree(extra);
+    Xfree(extra);
 
     if (buf == dpy->bufptr)
 	dpy->bufptr += length;
@@ -780,8 +771,7 @@ SendZImage(
 	  (req_yoffset * image->bytes_per_line) +
 	  ((req_xoffset * image->bits_per_pixel) >> 3);
     if ((image->bits_per_pixel == 4) && ((unsigned int) req_xoffset & 0x01)) {
-	if (! (shifted_src = (unsigned char *)
-	       Xmalloc((unsigned) (req->height * image->bytes_per_line)))) {
+	if (! (shifted_src = Xmalloc(req->height * image->bytes_per_line))) {
 	    UnGetReq(PutImage);
 	    return;
 	}
@@ -802,8 +792,7 @@ SendZImage(
 	((req_xoffset == 0) ||
 	 ((req_yoffset + req->height) < (unsigned)image->height))) {
 	Data(dpy, (char *)src, length);
-	if (shifted_src)
-	    Xfree((char *)shifted_src);
+	Xfree(shifted_src);
 	return;
     }
 
@@ -812,8 +801,8 @@ SendZImage(
 	dest = (unsigned char *)dpy->bufptr;
     else
 	if ((dest = (unsigned char *)
-	     _XAllocScratch(dpy, (unsigned long)(length))) == NULL) {
-	    if (shifted_src) Xfree((char *) shifted_src);
+	     _XAllocScratch(dpy, length)) == NULL) {
+	    Xfree(shifted_src);
 	    UnGetReq(PutImage);
 	    return;
 	}
@@ -840,8 +829,7 @@ SendZImage(
     else
 	_XSend(dpy, (char *)dest, length);
 
-    if (shifted_src)
-        Xfree((char *)shifted_src);
+    Xfree(shifted_src);
 }
 
 static void
@@ -1003,7 +991,7 @@ XPutImage (
 	    img.bits_per_pixel = dest_bits_per_pixel;
 	    img.bytes_per_line = ROUNDUP((dest_bits_per_pixel * width),
 					 dest_scanline_pad) >> 3;
-	    img.data = Xmalloc((unsigned) (img.bytes_per_line * height));
+	    img.data = Xmalloc(img.bytes_per_line * height);
 	    if (img.data == NULL)
 		return 0;
 	    _XInitImageFuncPtrs(&img);
